<?php

class MFSDN_Options {
    static $display_name_options = array(
        'nickname'           => 'Nickname',
        'email'              => 'Email',
        'username'           => 'Username',
        'firstname_lastname' => 'First Name + Last Name',
        'lastname_firstname' => 'Last Name + First Name',
        'lastname'           => 'Last Name',
        'firstname'          => 'First Name',
    );

    private $default_meta = array(
        'nickname',
        'first_name',
        'last_name',
        'description',
        'rich_editing',
        'syntax_highlighting',
        'comment_shortcuts',
        'admin_color',
        'use_ssl',
        'show_admin_bar_front',
        'locale',
        'wp_capabilities',
        'wp_user_level',
        'dismissed_wp_pointers',
        'show_welcome_panel',
        'session_tokens',
        'wp_dashboard_quick_press_last_post_id',
        'community-events-location'
    );

    private $settings;

    public function __construct() {
        $this->set_settings(json_decode(get_option('display_name_settings', ''), true));
        $this->set_default_names();

        add_action('admin_enqueue_scripts', array($this,'assets'));
        add_action('admin_menu', array($this, 'register_settings_page'));

        add_action('wp_ajax_setNewDisplayNamesSettings', array($this,'set_new_display_names_settings'));
        add_action('wp_ajax_getPopupContent', array($this,'get_popup_content'));
    }

    public function set_user_default_name($new_user_ID) {
        $names_settings = json_decode(get_option('display_name_settings', ''), true);
        $user = get_userdata($new_user_ID);
        $this->set_display_name_single($user, $names_settings);
    }

    public function set_user_default_name_mp($txn) {
        $names_settings = json_decode(get_option('display_name_settings', ''), true);
        $user = get_userdata($txn->user_id);
        $this->set_display_name_single($user, $names_settings);
    }

    public function set_new_display_names_settings() {
        if (!DOING_AJAX){
            wp_die();
        }

        if(!check_ajax_referer('display-name','nonce')){
            wp_die();
        }

        $new_settings_string_raw = isset($_POST['settings']) && !empty($_POST['settings']) ? json_encode($_POST['settings']) : '';
        $new_settings_string = sanitize_text_field($new_settings_string_raw);
        $is_updated = update_option('display_name_settings', $new_settings_string);
        $new_settings = json_decode($new_settings_string, true);
        $background_process = new MFSDN_Background_Display_Name;

        foreach ($new_settings as $role => $roleSettings) {
            if ($roleSettings['apply_to_current'] === 'true') {
                $users = get_users(array(
                    'role' => $role
                ));
                $background_process->cancel_process();
                foreach ($users as $user) {
                    $this->set_display_name($user, $new_settings, $background_process);
                }
                $background_process->save()->dispatch();
            }
        }

        die();
    }

    public function get_popup_content() {
        $message_deferred = "<h2 style='text-align: center;' class='hide-when-save'>This change will apply to all current users in this role. This action can't be undone.</h2><h4 style='text-align: center;' class='hide-when-save'>Are you sure you want to continue?</h4>";
        $message_default = "<h2 style='text-align: center;' class='hide-when-save'><h2 style='text-align: center;' class='hide-when-save'>Are you sure you want to change this settings?</h2>";
        $success_button = '<button style="margin: 0 5px;" class="button button-primary button-large hide-when-save">Ok</button>';
        $cancel_button = '<button style="margin: 0 5px;" class="button button-large hide-when-save" data-popup-close>Cancel</button>';
        $progress_image = '<img src="'. MFSDN_ASSET .'/img/loading.gif'.'" width="50px" class="show-when-loading" alt="loading bar" style="display:none;"><p class="show-when-loading" style="display:none; text-align: center;">It might take a while for your users to be affected. Please do not close the tab until the process is completed.</p>';
        print_r(json_encode(array(
            'save_display_names_checked' => array(
                'content'   => '<form id="save_display_names_checked" style="text-align: center;">'. $progress_image . $message_deferred . $success_button . $cancel_button.'</form>'
            ),
            'save_display_names_unchecked' => array(
                'content'   => '<form id="save_display_names_unchecked" style="text-align: center;">'. $progress_image . $message_default . $success_button . $cancel_button.'</form>'
            )
        )));
        die();
    }

    public function register_settings_page() {
        $parent_slug = 'users.php';
        $page_title = __('Publicity Names');
        $menu_title = __('Publicity Names');
        $capability = 'manage_options';
        $menu_slug = 'publicity-names';
        $function = array(
            $this,
            'render_content'
        );

        add_submenu_page($parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);
    }

    public function assets($suffix) {
        if ($suffix == 'user-edit.php' || $suffix == 'profile.php') {

            $user_id_raw = isset($_GET['user_id']) ? $_GET['user_id'] : get_current_user_id();
            $user_id = intval($user_id_raw);
            $user_info = get_userdata($user_id);
            $user_mail = $user_info->user_email;
            $role = $user_info->roles[0];
            $options = json_decode(get_option('display_name_settings'), true);
            wp_enqueue_script('main-js', MFSDN_ASSET . '/scripts/main.js', '', false, true);
            wp_localize_script('main-js', 'userInfo', array(
                'id'    => $user_id,
                'email' => $user_mail
            ));
        }
        if ($suffix === 'users_page_publicity-names') {
            wp_enqueue_script('popup-handler', MFSDN_ASSET . '/libs/popup-handler.js', array('jquery'), false, true);
            wp_enqueue_script('set-names-js', MFSDN_ASSET . '/scripts/set-names.js', array('jquery'), false, true);
            wp_localize_script('set-names-js', 'ajax', array(
                'url' => admin_url('admin-ajax.php')
            ));
        }
    }

    public function render_content() {
        require_once MFSDN_VIEW . '/name_form.php';
    }

    private function set_display_name_single($user, $user_settings) {
        $display_name = $this->process_name($user, $user_settings);

        wp_update_user(array(
            "ID"           => $user->ID,
            "display_name" => $display_name
        ));

    }

    private function set_display_name($user, $user_settings, $process) {
        $display_name = $this->process_name($user, $user_settings);

        $process->push_to_queue(wp_update_user(array(
                "ID"           => $user->ID,
                "display_name" => $display_name
        )));

    }

    private function process_name($user, $user_settings){
        $user_role = $user->roles[0];
        $user_display_name_slug = isset($user_settings[$user_role]['display_name']) ? $user_settings[$user_role]['display_name'] : 'nickname';

        switch ($user_display_name_slug) {
            case "nickname":
                $display_name = $user->nickname;
                break;
            case "email":
                $display_name = $user->user_email;
                break;
            case "username":
                $display_name = $user->user_login;
                break;
            case "firstname_lastname":
                $display_name = $user->user_firstname . ' ' . $user->user_lastname;
                break;
            case "lastname_firstname":
                $display_name = $user->user_lastname . ' ' . $user->user_firstname;
                break;
            case "lastname":
                $display_name = $user->user_lastname;
                break;
            case "firstname":
                $display_name = $user->user_firstname;
                break;
            default:
                $display_name = $user->nickname;
                break;
        }

        $custom_meta = $this->get_all_user_meta_keys(get_current_user_id());

        if(in_array($user_display_name_slug , $custom_meta)){
            $display_name = get_user_meta($user->ID, $user_display_name_slug, true);
        }

        if(get_option('mfsdn-member-choice')){
            if(get_option('mfsdn-member-choice') == 'true'){
                if(get_user_meta($user->ID, 'mfsdn-custom-display-name', true)){
                    $display_name = get_user_meta($user->ID, 'mfsdn-custom-display-name', true);
                }
            }
        }
        
        return $display_name;
    }

    private function set_settings($settings) {
        $this->settings = $settings;
    }

    private function set_default_names() {
        add_action('user_register', array(
            $this,
            'set_user_default_name'
        ));

        add_action('gform_user_registered', array(
            $this, 
            'set_user_default_name'), 10, 4
        );

        add_action('mepr-signup', array(
            $this,
            'set_user_default_name_mp'), 10
        );
    }

    private function get_all_user_meta_keys($user){
        global $wpdb;

        $sql = "SELECT * FROM " . $wpdb->prefix . "usermeta WHERE user_id = '$user'";
        $metas = $wpdb->get_results($sql);
        $returnable = array();
        
        foreach($metas as $meta){
            if(!in_array($meta->meta_key, $this->default_meta)){
                array_push($returnable, $meta->meta_key);
            }
        }

        return $returnable;
    }

    static function get_user_roles() {
        return wp_roles()->role_names;
    }

    static function get_user_options() {
        $options = self::$display_name_options;
        $output = '';
        foreach ($options as $option_slug => $option_name) {
            $output .= "<option value='$option_slug'>$option_name</option>";
        }

        return $output;
    }

}

new MFSDN_Options();